use crate::ui_screens::utils::centered_rect_size;
use std::fmt::Display;
use tui::buffer::Buffer;
use tui::layout::Rect;
use tui::style::{Color, Style};
use tui::widgets::*;

pub struct ButtonWidget {
    is_hovered: bool,
    label: String,
}

impl ButtonWidget {
    pub fn new<D: Display>(label: D, is_hovered: bool) -> Self {
        Self {
            label: label.to_string(),
            is_hovered,
        }
    }
}

impl Widget for ButtonWidget {
    fn render(self, area: Rect, buf: &mut Buffer) {
        let label = format!(" {} ", self.label);

        let area = centered_rect_size(label.len() as u16, 1, area);

        let input = Paragraph::new(label.as_ref()).style(match &self.is_hovered {
            false => Style::default().bg(Color::DarkGray),
            true => Style::default().fg(Color::White).bg(Color::Yellow),
        });

        input.render(area, buf);
    }
}
