use std::fmt::Display;

use tui::buffer::Buffer;
use tui::layout::Rect;
use tui::style::{Color, Style};
use tui::text::*;
use tui::widgets::{Block, Borders, Paragraph, Widget};

#[derive(Eq, PartialEq)]
pub enum InputMode {
    Normal,
    Editing,
}

pub struct TextEditorWidget {
    input_mode: InputMode,
    value: String,
    label: String,
}

impl TextEditorWidget {
    pub fn new<D: Display>(label: D, value: D, is_editing: bool) -> Self {
        Self {
            input_mode: match is_editing {
                true => InputMode::Editing,
                false => InputMode::Normal,
            },
            value: value.to_string(),
            label: label.to_string(),
        }
    }
}

impl Widget for TextEditorWidget {
    fn render(self, area: Rect, buf: &mut Buffer) {
        let span = Span::styled(
            self.value.to_string(),
            match &self.input_mode {
                InputMode::Normal => Style::default(),
                InputMode::Editing => Style::default().fg(Color::Yellow),
            },
        );

        let mut spans = vec![span];

        if self.input_mode == InputMode::Editing {
            spans.push(Span::styled(" ", Style::default().bg(Color::Yellow)))
        }

        let text = Text::from(Spans::from(spans));
        let input = Paragraph::new(text).block(
            Block::default()
                .borders(Borders::ALL)
                .title(self.label.as_ref()),
        );

        input.render(area, buf);
    }
}
